package com.example.furintiture

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.activity.enableEdgeToEdge
import androidx.compose.material3.Scaffold
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.lifecycle.lifecycleScope
import androidx.navigation.compose.rememberNavController
import com.example.furintiture.data.DataStoreSettings
import com.example.furintiture.ui.common.BottomNavigation
import com.example.furintiture.ui.common.Destination
import com.example.furintiture.ui.common.FurnitureBottomNavigation
import com.example.furintiture.ui.screen.Cart
import com.example.furintiture.ui.screen.FurnitureGlobalNavigation
import com.example.furintiture.ui.screen.Login
import com.example.furintiture.ui.screen.Main
import com.example.furintiture.ui.screen.Order
import com.example.furintiture.ui.screen.Registration
import com.example.furintiture.ui.screen.Splash
import com.example.furintiture.ui.theme.FurintitureTheme
import kotlinx.coroutines.launch

class MainActivity : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        enableEdgeToEdge()
        val dataStoreSettings = DataStoreSettings(applicationContext)
        setContent {
            FurintitureTheme {
                val navController = rememberNavController()
                val bottomBarIsVisible = remember { mutableStateOf(false) }
                val userUuid = remember { mutableStateOf("") }

                Scaffold(
                    bottomBar = {
                        if(bottomBarIsVisible.value) FurnitureBottomNavigation(){ destination ->
                            when(destination.route){
                                BottomNavigation.Home -> navController.navigate(Main(userUuid.value))
                                BottomNavigation.Cart -> navController.navigate(Cart(userUuid.value))
                                BottomNavigation.Order -> {
                                        navController.navigate(Order(userUuid.value))
                                }
                            }
                        }
                    }
                ) { paddingValues ->
                    paddingValues
                    FurnitureGlobalNavigation(dataStoreSettings, navController){
                        bottomBarIsVisible.value = it
                    }
                }
                LaunchedEffect(Unit) {
                    lifecycleScope.launch {
                        navController.clearBackStack(Splash)
                        dataStoreSettings.userUuidFlow.collect{
                            if(it.isEmpty()){
                                navController.navigate(Login){
                                    popUpTo(Splash){
                                        inclusive = true
                                    }
                                }
                            }else{
                                userUuid.value = it
                                navController.navigate(Main(it)){
                                    popUpTo(Splash){
                                        inclusive = true
                                    }
                                    popUpTo(Registration){
                                        inclusive = true
                                    }
                                    popUpTo(Login){
                                        inclusive = true
                                    }
                                }
                            }
                        }
                    }

                }
            }
        }

    }
}

