package com.example.furintiture.data.api

import com.example.furintiture.model.request.AddAddressRequest
import com.example.furintiture.model.request.AddToCartRequest
import com.example.furintiture.model.request.AddToWishlistRequest
import com.example.furintiture.model.request.ChangeCountFromCartRequest
import com.example.furintiture.model.request.CreateOrderRequest
import com.example.furintiture.model.request.LoginRequest
import com.example.furintiture.model.request.RegisterRequest
import com.example.furintiture.model.request.RemoveFromCartRequest
import com.example.furintiture.model.request.RemoveFromWishlistRequest
import com.example.furintiture.model.response.AllShopCategoryResponse
import com.example.furintiture.model.response.CartResponse
import com.example.furintiture.model.response.FurnitureCategoryResponse
import com.example.furintiture.model.response.FurnitureResponse
import com.example.furintiture.model.response.OrderResponse
import com.example.furintiture.model.response.SaleResponse
import com.example.furintiture.model.response.UserResponse
import retrofit2.http.Body
import retrofit2.http.DELETE
import retrofit2.http.GET
import retrofit2.http.POST
import retrofit2.http.PUT
import retrofit2.http.Path
import java.util.UUID
import kotlin.uuid.Uuid

interface FurnitureApi {
    @POST("/auth/login")
    suspend fun auth(@Body loginRequest: LoginRequest): UserResponse

    @POST("/auth/register")
    suspend fun register(@Body registerRequest: RegisterRequest): UserResponse

    @GET("/user/{uuid}/wishlist")
    suspend fun getWithListByUuid(@Path("uuid") uuid: UUID): List<FurnitureResponse>

    @GET("/user/{uuid}/cart")
    suspend fun getCartByUuid(@Path("uuid") uuid: UUID): List<CartResponse>

    @GET("/user/{uuid}/order")
    suspend fun getOrdersByUuid(@Path("uuid") uuid: UUID): List<OrderResponse>

    @GET("/user/{uuid}/profile")
    suspend fun getProfileByUuid(@Path("uuid") uuid: UUID): UserResponse

    @POST("/user/{uuid}/address")
    suspend fun addAddressByUuid(@Path("uuid") uuid: UUID, @Body addAddressRequest: AddAddressRequest)

    @POST("/wishlist")
    suspend fun addToWishlist(addToWishlistRequest: AddToWishlistRequest)

    @DELETE("/wishlist")
    suspend fun addToWishlist(removeFromWishlistRequest: RemoveFromWishlistRequest)

    @GET("/shop_category")
    suspend fun getAllShopCategory(): List<AllShopCategoryResponse>

    @GET("/shop_category/{shopCategoryId}/furniture")
    suspend fun getFurnitureByShopCategory(@Path("shopCategoryId") shopCategoryId: Long): List<FurnitureResponse>

    @GET("/sale")
    suspend fun getAllSales(): List<SaleResponse>

    @POST("/order")
    suspend fun createOrder(@Body createOrderRequest: CreateOrderRequest)

    @GET("/furniture")
    suspend fun getAllFurniture(): List<FurnitureResponse>

    @GET("/furniture/{furnitureId}")
    suspend fun getFurnitureById(@Path("furnitureId") furnitureId: Long): FurnitureResponse

    @GET("/category")
    suspend fun getAllFurnitureCategory(): List<FurnitureCategoryResponse>

    @GET("/category/{id}/furniture")
    suspend fun getFurnitureByCategory(@Path("id") categoryId: Long): List<FurnitureResponse>

    @POST("/cart")
    suspend fun addToCartByUuid(@Body addToCartRequest: AddToCartRequest)

    @PUT("/cart")
    suspend fun changeCountFromCartByUuid(@Body changeCountFromCartRequest: ChangeCountFromCartRequest)

    @DELETE("/cart")
    suspend fun removeFromCartByUuid(@Body removeFromCartRequest: RemoveFromCartRequest)
}