package com.example.furintiture.ui.common

import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.foundation.text.BasicTextField
import androidx.compose.material3.Icon
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.MutableState
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.input.PasswordVisualTransformation
import androidx.compose.ui.text.input.VisualTransformation
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.example.furintiture.R
import com.example.furintiture.ui.theme.Neutral_40
import com.example.furintiture.ui.theme.Neutral_70
import com.example.furintiture.ui.theme.Neutral_90

@Composable
fun BasieFurnitureTextField(
    value: String,
    onValueChange: (String) -> Unit,
    textColor: Color,
    label: @Composable () -> Unit,
    modifier: Modifier = Modifier,
    leadingIcon: @Composable (() -> Unit)? = null,
    visualTransformation: VisualTransformation = VisualTransformation.None,
    trailingIcon: @Composable (() -> Unit)? = null,
){
    BasicTextField(
        value = value,
        onValueChange = onValueChange,
        modifier = modifier
            .fillMaxWidth()
            .background(
                color = Color.White,
                shape = RoundedCornerShape(18.dp))
            .border(
                width = 1.dp, color = Neutral_40,
                shape = RoundedCornerShape(18.dp)
            ),
        singleLine = true,
        textStyle = TextStyle(
            color = Neutral_90,
            fontSize = 20.sp,
            fontFamily = FontFamily(Font(R.font.manrope))
        ),
        visualTransformation = visualTransformation,
        ){ innerTextField ->
        Row(
            modifier = Modifier
                .fillMaxWidth()
                .padding(vertical = 8.dp, horizontal = 18.dp),
            verticalAlignment = Alignment.CenterVertically
        ) {
            if (leadingIcon != null) {
                leadingIcon()
            }
            Spacer(modifier = Modifier.width(10.dp))
            Column {
                label()
                Spacer(modifier = Modifier.height(4.dp))
                innerTextField()
            }
            Spacer(modifier = Modifier.weight(1f))
            trailingIcon?.let {
                it()
            }
        }
    }
}






@Composable
fun FurnitureTextField(
    value: String,
    onValueChange: (String) -> Unit,
    textLabel: String,
    leadingResourceId: Int,
    tintColor: Color = Neutral_70,
    textColor: Color = Neutral_90,
){
    BasieFurnitureTextField(
        value = value,
        textColor = textColor,
        onValueChange = onValueChange,
        label = {
            Text(
                textLabel,
                color = textColor,
                style = TextStyle(
                    color = Neutral_90,
                    fontSize = 15.sp,
                    fontFamily = FontFamily(Font(R.font.manrope))
                )
            )
                },
        leadingIcon = { Icon(
            modifier = Modifier.size(24.dp),
            painter = painterResource(leadingResourceId),
            tint = tintColor,
            contentDescription = null)
        }
    )
}


@Composable
fun FurniturePasswordTextField(
    value: String,
    onValueChange: (String) -> Unit,
    tintColor: Color = Neutral_70,
    textColor: Color = Neutral_90,
){
    val passwordIsVisible = remember { mutableStateOf(false) }
        BasieFurnitureTextField(
            value = value,
            textColor = textColor,
            onValueChange = onValueChange,
            label = {
                Text("Password",
                    color = textColor,
                    style = TextStyle(
                        color = Neutral_90,
                        fontSize = 15.sp,
                        fontFamily = FontFamily(Font(R.font.manrope))
                    ))
                    },
            visualTransformation = if(passwordIsVisible.value) VisualTransformation.None else PasswordVisualTransformation('*'),
            leadingIcon = { Icon(
                modifier = Modifier.size(24.dp),
                painter = painterResource(R.drawable.lock_icon),
                tint = tintColor,
                contentDescription = null)
            },
            trailingIcon = { Icon(
                modifier =
                Modifier.size(20.dp).clickable {
                    passwordIsVisible.value = !passwordIsVisible.value
                },
                tint = tintColor,
                painter = painterResource(R.drawable.fi_sr_eye_1),
                contentDescription = null)
            }
        )

}