package com.example.furintiture.ui.common

import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.wrapContentHeight
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.Home
import androidx.compose.material.icons.filled.Menu
import androidx.compose.material.icons.filled.ShoppingCart
import androidx.compose.material3.Icon
import androidx.compose.material3.NavigationBar
import androidx.compose.material3.NavigationBarItem
import androidx.compose.material3.NavigationBarItemColors
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableIntStateOf
import androidx.compose.runtime.saveable.rememberSaveable
import androidx.compose.runtime.setValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.graphics.vector.ImageVector
import com.example.furintiture.ui.theme.Neutral_40
import com.example.furintiture.ui.theme.Primary

public enum class Destination(
    val route: BottomNavigation,
    val label: String,
    val icon: ImageVector,
    val contentDescription: String
) {
    HOME(BottomNavigation.Home, "Основная", Icons.Default.Home, "Songs"),
    CART(BottomNavigation.Cart, "Корзина", Icons.Default.ShoppingCart, "Album"),
    ORDER(BottomNavigation.Order, "Заказы", Icons.Default.Menu, "Playlist")
}

sealed class BottomNavigation{
    data object Home: BottomNavigation()
    data object Cart: BottomNavigation()
    data object Order: BottomNavigation()
}

@Composable
fun FurnitureBottomNavigation(
    onChangeBottomItem: (Destination) -> Unit
) {

    val startDestination = Destination.HOME
    var selectedDestination by rememberSaveable { mutableIntStateOf(startDestination.ordinal) }
    NavigationBar(
        modifier = Modifier
            .fillMaxWidth()
            .wrapContentHeight(),
        containerColor = Color.White
    ) {
        Destination.entries.forEachIndexed { index, destination ->
            NavigationBarItem(
                selected = selectedDestination == index,
                onClick = {
                    selectedDestination = index
                    onChangeBottomItem(destination)
                },
                icon = {
                    Icon(
                        destination.icon,
                        contentDescription = destination.contentDescription
                    )
                },
                label = { Text(destination.label) },
                colors = NavigationBarItemColors(
                    selectedIconColor = Primary,
                    selectedTextColor = Primary,
                    selectedIndicatorColor = Color.Transparent,
                    unselectedIconColor = Neutral_40,
                    unselectedTextColor = Neutral_40,
                    disabledIconColor = Neutral_40,
                    disabledTextColor = Neutral_40
                )
            )
        }
    }
}