package com.example.furintiture.ui.common

import android.content.res.Resources.Theme
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.example.furintiture.R
import com.example.furintiture.ui.theme.FurintitureTheme
import com.example.furintiture.ui.theme.Primary

@Composable
fun FurnitureButton(
    text: String,
    modifier: Modifier = Modifier,
    onClick : () -> Unit,
    ){
    Button(
        modifier = modifier
            .fillMaxWidth()
            .height(43.dp)
            .clip(shape = RoundedCornerShape(8.dp))
        ,
        colors = ButtonDefaults.buttonColors().copy(
            containerColor = Primary,
            contentColor = Color.White,
            disabledContainerColor = Primary,
            disabledContentColor = Color.White
        ),
        onClick = onClick
    ) {
        Text(
            text = text,
            style = TextStyle(
                fontFamily = FontFamily(Font(R.font.manrope)),
                fontWeight = FontWeight.Bold,
                fontSize = 16.sp
            )
        )
    }
}

@Preview
@Composable
fun FurniturePreview(){
    FurnitureButton(
        "Войти"
    ){
    }
}