package com.example.furintiture.ui.common

import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.layout.wrapContentHeight
import androidx.compose.foundation.layout.wrapContentSize
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextOverflow
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import coil3.compose.AsyncImage
import coil3.request.ImageRequest
import coil3.request.crossfade
import com.example.furintiture.R
import com.example.furintiture.model.response.FurnitureCategoryResponse
import com.example.furintiture.model.response.FurnitureResponse
import com.example.furintiture.ui.theme.Neutral_10
import com.example.furintiture.ui.theme.Neutral_20
import java.math.BigDecimal

@Composable
fun FurnitureCard(
    furnitureResponse: FurnitureResponse,
    onFurnitureClick: (FurnitureResponse) -> Unit
){
    Column(
        modifier = Modifier
            .wrapContentHeight()
            .width(150.dp)
            .background(color = Neutral_10, shape = RoundedCornerShape(14.dp))
            .padding(16.dp)
            .clickable {
                onFurnitureClick(furnitureResponse)
            },
        horizontalAlignment = Alignment.CenterHorizontally,
        verticalArrangement = Arrangement.Center
    ) {
        Box(
            modifier = Modifier.wrapContentSize()
        ) {
            AsyncImage(
                modifier = Modifier
                    .size(120.dp, 120.dp)
                ,
                model = ImageRequest
                    .Builder(LocalContext.current)
                    .data(furnitureResponse.url)
                    .crossfade(true)
                    .build(),
                placeholder = painterResource(R.drawable.images),
                contentScale = ContentScale.FillWidth,
                contentDescription = null
            )
            Text(
                text = "${furnitureResponse.sale.multiply(BigDecimal(100)).toInt()}% OFF",
                modifier = Modifier
                    .align(Alignment.BottomStart)
                    .background(
                        color = Color.Red,
                        shape = RoundedCornerShape(10.dp)
                    )
                    .padding(
                        vertical = 4.dp,
                        horizontal = 6.dp
                    ),
                style = TextStyle(
                    color = Color.White,
                    fontWeight = FontWeight.SemiBold,
                    fontFamily = FontFamily(Font(R.font.manrope)),
                    fontSize = 10.sp
                )
            )
        }
        Spacer(modifier = Modifier.height(4.dp))
        Column(
            modifier = Modifier.wrapContentHeight()
        ) {
            Text(
                text = furnitureResponse.name,
                style = TextStyle(
                    color = com.example.furintiture.ui.theme.Text,
                    fontFamily = FontFamily(Font(R.font.manrope)),
                    fontSize = 14.sp
                ),
                maxLines = 1,
                overflow = TextOverflow.Ellipsis
            )
            Text(
                text = "${furnitureResponse.price} ₽",
                style = TextStyle(
                    color = com.example.furintiture.ui.theme.Text,
                    fontFamily = FontFamily(Font(R.font.manrope)),
                    fontSize = 20.sp,
                    fontWeight = FontWeight.Bold
                )
            )
        }
    }
}

@Composable
@Preview
fun FurnitureCardPreview(){
    val furnitureResponse = FurnitureResponse(
        id = 1,
        name = "Стул",
        price = BigDecimal("1000.5"),
        description = "!@3",
        sale = BigDecimal("0.40"),
        url = "https://laurendanger.com/wp-content/uploads/sites/33/2024/10/IMG_3826.jpeg",
        category = FurnitureCategoryResponse(
            id = 1,
            name = "!@3"
        ),
        shopCategories = emptyList()
    )
    FurnitureCard(furnitureResponse){

    }
}