package com.example.furintiture.ui.common

import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxHeight
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.shadow
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import coil3.compose.AsyncImage
import coil3.request.ImageRequest
import coil3.request.crossfade
import com.example.furintiture.R
import com.example.furintiture.model.response.CartResponse
import com.example.furintiture.ui.theme.Neutral_10
import java.math.BigDecimal

@Composable
fun FurnitureCartCard(cartResponse: CartResponse) {
    Row(
        horizontalArrangement = Arrangement.Center,
        verticalAlignment = Alignment.CenterVertically,
        modifier = Modifier
            .fillMaxWidth()
            .background(color = Neutral_10, shape = RoundedCornerShape(16.dp))
            .padding(16.dp)
    ) {
        AsyncImage(
            modifier = Modifier
                .size(100.dp, 100.dp)
            ,
            model = ImageRequest
                .Builder(LocalContext.current)
                .data(cartResponse.furnitureResponse.url)
                .crossfade(true)
                .build(),
            placeholder = painterResource(R.drawable.images),
            contentScale = ContentScale.FillWidth,
            contentDescription = null
        )
        Spacer(Modifier.width(16.dp))
        Column(
            modifier = Modifier
                .fillMaxSize()
                .fillMaxHeight()
        ) {
            Text(
                text = cartResponse.furnitureResponse.name,
                style = TextStyle(
                    color = com.example.furintiture.ui.theme.Text,
                    fontFamily = FontFamily(Font(R.font.manrope)),
                    fontSize = 24.sp
                )
            )
            Text(
                text = "${cartResponse.furnitureResponse.price} ₽",
                style = TextStyle(
                    color = com.example.furintiture.ui.theme.Text,
                    fontFamily = FontFamily(Font(R.font.manrope)),
                    fontSize = 36.sp,
                    fontWeight = FontWeight.Bold
                )
            )
            Spacer(modifier = Modifier.width(8.dp))
            Text(
                text = "${cartResponse.furnitureResponse.sale.multiply(BigDecimal(100)).toInt()}% OFF",
                modifier = Modifier
                    .background(
                        color = Color.Red,
                        shape = RoundedCornerShape(10.dp)
                    )
                    .padding(
                        vertical = 4.dp,
                        horizontal = 6.dp
                    ),
                style = TextStyle(
                    color = Color.White,
                    fontWeight = FontWeight.SemiBold,
                    fontFamily = FontFamily(Font(R.font.manrope)),
                    fontSize = 16.sp
                )
            )
            Text(
                text = "Количество: ${cartResponse.count}",
                style = TextStyle(
                    color = com.example.furintiture.ui.theme.Text,
                    fontFamily = FontFamily(Font(R.font.manrope)),
                    fontSize = 24.sp
                )
            )
        }
    }
}