package com.example.furintiture.ui.common

import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.PaddingValues
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.lazy.LazyRow
import androidx.compose.foundation.lazy.items
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.capitalize
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.intl.Locale
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.example.furintiture.R
import com.example.furintiture.model.response.FurnitureResponse
import com.example.furintiture.model.response.ShopCategoryResponse
import com.example.furintiture.ui.theme.Primary

@Composable
fun FurnitureHorizontalList(
    categoryName: String, categoryFurnitureList: List<FurnitureResponse>,
    onAllFurnitureClick: () -> Unit,
    onFurnitureClick: (FurnitureResponse) -> Unit,
) {
    Column(
        modifier = Modifier.height(300.dp).fillMaxWidth()
    ) {
        Row(
           modifier =
           Modifier.height(30.dp)
               .fillMaxWidth(),
            verticalAlignment = Alignment.CenterVertically
        ) {
            Text(
                modifier = Modifier.weight(1f),
                text = categoryName.replaceFirstChar { it.titlecaseChar() },
                style = TextStyle(
                color = com.example.furintiture.ui.theme.Text,
                fontFamily = FontFamily(Font(R.font.manrope)),
                fontSize = 20.sp,
                fontWeight = FontWeight.Bold)
            )
            Text(
                modifier = Modifier.clickable {
                    onAllFurnitureClick()
                },
                text = "Больше товаров",
                style = TextStyle(
                    color = Primary,
                    fontFamily = FontFamily(Font(R.font.manrope)),
                    fontSize = 14.sp,
                    fontWeight = FontWeight.Bold
                )
            )
        }
        Spacer(modifier = Modifier.height(16.dp))
        LazyRow(
            modifier = Modifier.fillMaxWidth(),
            horizontalArrangement = Arrangement.spacedBy(16.dp)
        ) {
            items(categoryFurnitureList.size){ item ->
                FurnitureCard(categoryFurnitureList[item]){ furniture ->
                    onFurnitureClick(furniture)
                }
            }
        }
    }
}