package com.example.furintiture.ui.common

import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.lazy.LazyRow
import androidx.compose.foundation.lazy.items
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.example.furintiture.R
import com.example.furintiture.model.response.OrderResponse
import com.example.furintiture.ui.theme.Primary
import kotlinx.datetime.LocalDateTime
import kotlinx.datetime.format
import kotlinx.datetime.format.DateTimeComponents
import kotlinx.datetime.format.DateTimeFormat
import kotlinx.datetime.format.DateTimeFormatBuilder
import kotlinx.datetime.format.byUnicodePattern

@Composable
fun FurnitureOrderCard(orderResponse: OrderResponse) {

    Column(
        modifier = Modifier
            .fillMaxWidth()
    ) {
        Row(
            modifier =
            Modifier.height(30.dp)
                .fillMaxWidth(),
            verticalAlignment = Alignment.CenterVertically
        ) {
            Text(
                modifier = Modifier.weight(1f),
                text = "Номер заказа: ${orderResponse.id}",
                style = TextStyle(
                    color = com.example.furintiture.ui.theme.Text,
                    fontFamily = FontFamily(Font(R.font.manrope)),
                    fontSize = 20.sp,
                    fontWeight = FontWeight.Bold)
            )
            Text(
                text = "Статус заказа: ${orderResponse.orderStatus.name}",
                style = TextStyle(
                    color = Primary,
                    fontFamily = FontFamily(Font(R.font.manrope)),
                    fontSize = 14.sp,
                    fontWeight = FontWeight.Bold
                )
            )
        }
        val format = LocalDateTime.Format {
            byUnicodePattern("uuuu-MM-dd HH:mm")
        }
        Text(
            text = "Дата заказа: ${format.format(orderResponse.dateTime)}",
            style = TextStyle(
                color = com.example.furintiture.ui.theme.Text,
                fontFamily = FontFamily(Font(R.font.manrope)),
                fontSize = 14.sp
            )
        )
        Text(
            text = "Итого: ${orderResponse.orderTotalSum}",
            style = TextStyle(
                color = com.example.furintiture.ui.theme.Text,
                fontFamily = FontFamily(Font(R.font.manrope)),
                fontSize = 14.sp
            )
        )
        Text(
            text = "По адресу: ${orderResponse.addressResponse.address}",
            style = TextStyle(
                color = com.example.furintiture.ui.theme.Text,
                fontFamily = FontFamily(Font(R.font.manrope)),
                fontSize = 14.sp
            )
        )
        LazyRow(
            modifier = Modifier.fillMaxWidth(),
            horizontalArrangement = Arrangement.spacedBy(16.dp)
        ) {
            items(orderResponse.orderSet){ orderSet ->
                FurnitureCard(orderSet.furnitureResponse) {

                }
            }
        }
    }
}