package com.example.furintiture.ui.screen

import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.navigation.NavHostController
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.toRoute
import com.example.furintiture.configure.UuidSerializer
import com.example.furintiture.data.DataStoreSettings
import com.example.furintiture.ui.screen.cart.CartScreen
import com.example.furintiture.ui.screen.detail.DetailScreen
import com.example.furintiture.ui.screen.furniture.FurnitureScreen
import com.example.furintiture.ui.screen.login.LoginScreen
import com.example.furintiture.ui.screen.main.MainScreen
import com.example.furintiture.ui.screen.order.OrderScreen
import com.example.furintiture.ui.screen.registration.RegistrationScreen
import com.example.furintiture.ui.screen.splashscreen.SplashScreen
import kotlinx.serialization.Serializable
import java.util.UUID

@Composable
fun FurnitureGlobalNavigation(
    dataStoreSettings: DataStoreSettings,
    navHostController: NavHostController,
    onBottomBarVisibleEvent: (Boolean) -> Unit
) {
       NavHost(
            modifier = Modifier,
            navController = navHostController,
            startDestination = Splash
        ){
            composable<Splash> {
                SplashScreen()
                onBottomBarVisibleEvent(false)
            }
           composable<Registration> {
               RegistrationScreen(dataStoreSettings){
                   navHostController.navigate(Login)
               }
               onBottomBarVisibleEvent(false)

           }
           composable<Login> {
               LoginScreen(dataStoreSettings){
                   navHostController.navigate(Registration)
               }
               onBottomBarVisibleEvent(false)

           }

           composable<Detail>{ navBackStackEntry ->
               val detail: Detail = navBackStackEntry.toRoute()
               DetailScreen(detail){
                   navHostController.navigateUp()
               }
               onBottomBarVisibleEvent(false)

           }
           composable<Furniture>{navBackStackEntry ->
               val furniture: Furniture = navBackStackEntry.toRoute()

               FurnitureScreen(uuid = furniture.uuid, onClosePressed = {
                   navHostController.navigateUp()
               }) {
                   navHostController.navigate(it)
               }
               onBottomBarVisibleEvent(false)
           }
            composable<Cart>{ navBackStackEntry ->
                val cart: Cart = navBackStackEntry.toRoute()
                CartScreen(cart.uuid)
            }
           composable<Order>{ navBackStackEntry ->
               val order: Order = navBackStackEntry.toRoute()
               OrderScreen(order.uuid)
           }
           composable<Main> { navBackStackEntry ->
               val main: Main = navBackStackEntry.toRoute()
               MainScreen(
                   main.uuid,
                   onNavigateToFurniture = { furniture ->
                       navHostController.navigate(furniture)
                   }
               ){ detail ->
                   navHostController.navigate(detail)
               }
               onBottomBarVisibleEvent(true)
           }

    }
}


@Serializable
data class Main(
    val uuid: String
)



@Serializable
data class Detail(
    val furnitureId: Long,
    val uuid: String
)

@Serializable
data class Cart(
    val uuid: String
)

@Serializable
data class Order(
    val uuid: String
)

@Serializable
object Login


@Serializable
data class Furniture(
    val uuid: String
)


@Serializable
object Registration

@Serializable
object Splash