package com.example.furintiture.ui.screen.bottomsheet

import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.ModalBottomSheet
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.collectAsState
import androidx.compose.ui.Modifier
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.example.furintiture.R
import com.example.furintiture.model.request.AddAddressRequest
import com.example.furintiture.model.response.AddressResponse
import com.example.furintiture.ui.common.BasieFurnitureTextField
import com.example.furintiture.ui.common.FurnitureButton
import com.example.furintiture.ui.theme.Neutral_90
import kotlinx.coroutines.flow.MutableStateFlow

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun FurnitureAddressBottomSheet(
    addressResponse: AddressResponse?,
    viewModel: FurnitureAddressBottomSheetViewModel,
    createAddressCallback: (AddAddressRequest) -> Unit,
) {
    val state = viewModel.furnitureAddressState.collectAsState()
    LaunchedEffect(addressResponse) {
        if (addressResponse != null){
            viewModel.setAddress(address = addressResponse.address)
            viewModel.setFloor(floor = addressResponse.floor.toString())
            viewModel.setApartment(apartment = addressResponse.apartment.toString())
            viewModel.setComment(comment = addressResponse.comment ?: "")
        }
    }
    ModalBottomSheet(
        onDismissRequest = {
            createAddressCallback(state.value)
        }
    ){
    Column(
        modifier = Modifier
            .padding(horizontal = 16.dp, vertical = 8.dp)
    ) {
        BasieFurnitureTextField(
            value = state.value.address,
            onValueChange = {viewModel.setAddress(it)},
            textColor = Neutral_90,
            label = {
                Text(
                    "Адрес",
                    color = Neutral_90,
                    style = TextStyle(
                        color = Neutral_90,
                        fontSize = 15.sp,
                        fontFamily = FontFamily(Font(R.font.manrope))
                    )
                )
            }
        )
        Spacer(Modifier.height(16.dp))
        Row(
            modifier = Modifier.fillMaxWidth()
        ){
            BasieFurnitureTextField(
                modifier = Modifier.weight(0.5f),
                value = if(state.value.floor == null) "" else state.value.floor.toString(),
                onValueChange = {viewModel.setFloor(it)},
                textColor = Neutral_90,
                label = {
                    Text(
                        "Этаж",
                        color = Neutral_90,
                        style = TextStyle(
                            color = Neutral_90,
                            fontSize = 15.sp,
                            fontFamily = FontFamily(Font(R.font.manrope))
                        )
                    )
                }
            )
            BasieFurnitureTextField(
                modifier = Modifier.weight(0.5f),
                value = if(state.value.apartment == null) "" else state.value.apartment.toString(),
                onValueChange = {viewModel.setApartment(it)},
                textColor = Neutral_90,
                label = {
                    Text(
                        "Квартира",
                        color = Neutral_90,
                        style = TextStyle(
                            color = Neutral_90,
                            fontSize = 15.sp,
                            fontFamily = FontFamily(Font(R.font.manrope))
                        )
                    )
                }
            )
        }
        Spacer(Modifier.height(16.dp))
        BasieFurnitureTextField(
            value = state.value.comment ?: "",
            onValueChange = {viewModel.setComment(it)},
            textColor = Neutral_90,
            label = {
                Text(
                    "Комментарий курьеру",
                    color = Neutral_90,
                    style = TextStyle(
                        color = Neutral_90,
                        fontSize = 15.sp,
                        fontFamily = FontFamily(Font(R.font.manrope))
                    )
                )
            }
        )
        Spacer(Modifier.height(16.dp))
        val text = if(addressResponse != null) "Изменить" else "Добавить"
        FurnitureButton(
            text = text
        ) {
            createAddressCallback(state.value)
        }
    }
    }
}