package com.example.furintiture.ui.screen.cart

import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.PaddingValues
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.material3.Scaffold
import androidx.compose.material3.SnackbarHost
import androidx.compose.material3.SnackbarHostState
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.derivedStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.rememberCoroutineScope
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.lifecycle.viewmodel.compose.viewModel
import com.example.furintiture.R
import com.example.furintiture.ui.common.FurnitureButton
import com.example.furintiture.ui.common.FurnitureCartCard
import com.example.furintiture.ui.theme.Neutral_20
import kotlinx.coroutines.launch
import java.math.BigDecimal

@Composable
fun CartScreen(
    uuid: String
) {
    val snackbarHostState  = remember { SnackbarHostState() }
    val coroutineScope = rememberCoroutineScope()
    val viewModel: CartScreenViewModel = viewModel { CartScreenViewModel(uuid) }
    Scaffold(
        snackbarHost = {
            SnackbarHost(hostState = snackbarHostState)
        },
        contentColor = Neutral_20
    ) { paddingValues ->
        CartScreenContent(viewModel, paddingValues){
            coroutineScope.launch {
                snackbarHostState.showSnackbar(it)
            }
        }
    }
}

@Composable
fun CartScreenContent(
    viewModel: CartScreenViewModel,
    paddingValues: PaddingValues,
    onErrorCallback : (String) -> Unit
){
    val state = viewModel.cartScreenState.collectAsState()
    val totalSum = remember { derivedStateOf {
        state.value.cartResponse.sumOf { cart ->
            BigDecimal(cart.count) * cart.furnitureResponse.price
        }
    }}

    LaunchedEffect(state.value.error) {
        state.value.error?.let(onErrorCallback)
        state.value.error = null
    }
    Column(
        modifier = Modifier
            .padding(paddingValues)
            .fillMaxSize()
            .padding(horizontal = 16.dp)
            .padding(bottom = 100.dp)


    ) {
        LazyColumn(
            modifier = Modifier.fillMaxSize(),
            verticalArrangement = Arrangement.spacedBy(16.dp)
        ) {
            items(state.value.cartResponse.size){ item ->
                FurnitureCartCard(state.value.cartResponse[item])
            }
            if(totalSum.value > BigDecimal(0)){
                item {
                    Spacer(Modifier.height(16.dp))
                    Text(
                        "Итого: ${totalSum.value}",
                        style  = TextStyle(
                            color = com.example.furintiture.ui.theme.Text,
                            fontFamily = FontFamily(Font(R.font.manrope)),
                            fontSize = 36.sp,
                            fontWeight = FontWeight.Bold
                        )
                    )
                }
                item {
                    Spacer(Modifier.height(16.dp))
                    FurnitureButton(
                        modifier = Modifier.height(60.dp),
                        text = "Оформить заказ"
                    ) {
                        viewModel.createOrder()
                    }
                }
            }
        }

    }
}