package com.example.furintiture.ui.screen.cart

import androidx.compose.runtime.derivedStateOf
import androidx.compose.runtime.mutableStateOf
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.example.furintiture.data.RetrofitClient
import com.example.furintiture.model.request.CreateOrderItemRequest
import com.example.furintiture.model.request.CreateOrderRequest
import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.flow.asStateFlow
import kotlinx.coroutines.flow.update
import kotlinx.coroutines.launch
import java.math.BigDecimal
import java.util.UUID

class CartScreenViewModel(private val uuid: String): ViewModel() {
    private val _cartScreenState = MutableStateFlow(CartScreenState())
    val cartScreenState = _cartScreenState.asStateFlow()
    val totalSum = derivedStateOf { cartScreenState.value.cartResponse.sumOf { cart ->
        BigDecimal(cart.count) * cart.furnitureResponse.price }
    }
    init {
        try {
            init()
        }
        catch (e: Exception){
            _cartScreenState.update {
                it.copy(error = e.message)
            }
        }
    }
    fun createOrder(){
        viewModelScope.launch {
            try {
                val addresId = RetrofitClient.api.getProfileByUuid(UUID.fromString(uuid)).address?.addressId
                if (addresId == null){
                    _cartScreenState.update {
                        it.copy(error = "Нельзя сделать заказ без адрес")
                    }
                    return@launch
                }
                val createOrderRequest = CreateOrderRequest(
                    userUuid = UUID.fromString(uuid),
                    addressId = addresId.toLong(),
                    orderStatus = 1,
                    orderTotalSum = cartScreenState.value.cartResponse.sumOf { cart ->
                        BigDecimal(cart.count) * cart.furnitureResponse.price
                    },
                    orderSet = cartScreenState.value.cartResponse.map {
                        CreateOrderItemRequest(
                            furnitureId = it.furnitureResponse.id,
                            furniturePrice = it.furnitureResponse.price,
                            count = it.count
                        )
                    }
                )
               RetrofitClient.api.createOrder(createOrderRequest)
                _cartScreenState.update {
                    it.copy(cartResponse = emptyList())
                }
            }
            catch (e: Exception){
                _cartScreenState.update {
                    it.copy(error = e.message)
                }
            }

        }
    }
    private fun init(){

        viewModelScope.launch {
            val cart = RetrofitClient.api.getCartByUuid(UUID.fromString(uuid))
            _cartScreenState.update {
                it.copy(cartResponse = cart)
            }
        }
    }
}