package com.example.furintiture.ui.screen.detail

import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.example.furintiture.data.RetrofitClient
import com.example.furintiture.model.request.AddToCartRequest
import com.example.furintiture.model.request.ChangeCountFromCartRequest
import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.flow.asStateFlow
import kotlinx.coroutines.flow.update
import kotlinx.coroutines.launch
import java.util.UUID

class DetailScreenViewModel(private val furnitureId: Long, private val uuidUser: String): ViewModel() {
    private val _detailScreenState = MutableStateFlow(DetailScreenState())
    val detailScreenState = _detailScreenState.asStateFlow()
    init {
        init()
    }

    fun addToCart(){
        viewModelScope.launch {
            try {
                RetrofitClient.api.addToCartByUuid(
                    AddToCartRequest(
                        uuid = UUID.fromString(uuidUser),
                        furnitureId = furnitureId,
                        count = 1
                    )
                )
                _detailScreenState.update {
                    it.copy(error = "Успешно добавлено")
                }
            }
            catch (e: Exception){
                _detailScreenState.update {
                    it.copy(error = e.message)
                }
            }
        }
    }

    private fun init(){
        viewModelScope.launch {
            try {
                val result = RetrofitClient.api.getFurnitureById(furnitureId)
                _detailScreenState.update {
                    it.copy(furnitureResponse = result)
                }
            }
            catch (e: Exception){
                println(e.message)
            }
        }
    }
}