package com.example.furintiture.ui.screen.furniture

import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.PaddingValues
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.lazy.grid.GridCells
import androidx.compose.foundation.lazy.grid.LazyVerticalGrid
import androidx.compose.foundation.lazy.grid.items
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.Close
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.Scaffold
import androidx.compose.material3.SnackbarHost
import androidx.compose.material3.SnackbarHostState
import androidx.compose.material3.TopAppBar
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.remember
import androidx.compose.runtime.rememberCoroutineScope
import androidx.compose.ui.Modifier
import androidx.compose.ui.unit.dp
import androidx.lifecycle.viewmodel.compose.viewModel
import com.example.furintiture.ui.common.FurnitureCard
import com.example.furintiture.ui.screen.Detail
import kotlinx.coroutines.launch

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun FurnitureScreen(
    uuid: String,
    onClosePressed: () -> Unit,
    onNavigateToDetail: (Detail) -> Unit
) {
    val snackbarHostState  = remember { SnackbarHostState() }
    val coroutineScope = rememberCoroutineScope()
    val viewModel = viewModel {
        FurnitureScreenViewModel()
    }
    Scaffold(
        snackbarHost = {
            SnackbarHost(hostState = snackbarHostState)
        },
        topBar = {
            TopAppBar(
                title = {},
                navigationIcon = {
                    IconButton (
                        onClick = {
                            onClosePressed()
                        }
                    ){
                        Icon(
                            imageVector = Icons.Default.Close,
                            contentDescription = null
                        )
                    }
                }
            )
        },
    ) { paddingValues ->
        FurnitureContent(uuid, viewModel, paddingValues, onNavigateToDetail){
            coroutineScope.launch {
                snackbarHostState.showSnackbar(message = it)
            }
        }
    }
}

@Composable
fun FurnitureContent(
    uuid: String,
    furnitureScreenViewModel: FurnitureScreenViewModel,
    paddingValues: PaddingValues,
    onNavigateToDetail: (Detail) -> Unit,
    onErrorCallback: (String) -> Unit
){
    val state = furnitureScreenViewModel.furnitureScreenState.collectAsState()

    LaunchedEffect(state.value.error) {
        state.value.error?.let(onErrorCallback)
        state.value.error = null
    }

    Column(
        modifier = Modifier
            .padding(paddingValues)
            .fillMaxSize()
            .padding(horizontal = 16.dp)
    ) {
        LazyVerticalGrid (
            modifier = Modifier
                .fillMaxSize(),
            horizontalArrangement = Arrangement.spacedBy(8.dp),
            verticalArrangement = Arrangement.spacedBy(8.dp),
            columns = GridCells.Adaptive(minSize = 130.dp)
        ){
            items(state.value.furnitureList){ it ->
                FurnitureCard(it) {
                    onNavigateToDetail(Detail(uuid = uuid, furnitureId = it.id))
                }
            }
        }
    }
}