package com.example.furintiture.ui.screen.login

import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.example.furintiture.data.DataStoreSettings
import com.example.furintiture.data.RetrofitClient
import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.flow.asStateFlow
import kotlinx.coroutines.flow.update
import kotlinx.coroutines.launch

class LoginScreenViewModel(private val dataStoreSettings: DataStoreSettings): ViewModel() {
    private val _loginScreenState = MutableStateFlow(LoginScreenState())
    val loginScreenState = _loginScreenState.asStateFlow()

    fun setPassword(password: String){
        _loginScreenState.update {
            it.copy(request = it.request.copy(password = password))
        }
    }
    fun setEmail(email: String){
        _loginScreenState.update {
            it.copy(request = it.request.copy(email = email))
        }
    }
    fun login(){
        if(!validate()) return
        viewModelScope.launch {
            try {
                val result =  RetrofitClient.api.auth(loginScreenState.value.request)
                dataStoreSettings.setUuid(result.userUuid)
            }
            catch (e: Exception){
                _loginScreenState.update {
                    it.copy(error = e.message)
                }
            }
        }
    }
    private fun validate(): Boolean{
        if (_loginScreenState.value.request.email.isEmpty()){
            _loginScreenState.update {
                it.copy(error = "Введите email")
            }
            return false
        }
        if (_loginScreenState.value.request.password.isEmpty()){
            _loginScreenState.update {
                it.copy(error = "Введите password")
            }
            return false
        }
        return true
    }
}