package com.example.furintiture.ui.screen.main

import androidx.compose.runtime.saveable.autoSaver
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.example.furintiture.data.RetrofitClient
import com.example.furintiture.model.request.AddAddressRequest
import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.flow.asStateFlow
import kotlinx.coroutines.flow.update
import kotlinx.coroutines.launch
import java.util.UUID

class MainScreenViewModel(private val uuid: String): ViewModel() {
    private val _mainScreenState = MutableStateFlow(MainScreenState())
    val mainScreenState = _mainScreenState.asStateFlow()

    init {
        try {
            init()
        }
        catch (e: Exception){
            _mainScreenState.update {
                it.copy(error = e.message)
            }
        }
    }

    private fun init(){
        viewModelScope.launch {
            val sales = RetrofitClient.api.getAllSales()
            _mainScreenState.update {
                it.copy(sales = sales)
            }
            val allCategory  = RetrofitClient.api.getAllShopCategory()
            _mainScreenState.update {
                it.copy(shopCategories = allCategory)
            }
            val profile = RetrofitClient.api.getProfileByUuid(UUID.fromString(uuid))
            _mainScreenState.update {
                it.copy(profile = profile)
            }
        }
    }

    fun addAddress(addressRequest: AddAddressRequest){
        viewModelScope.launch {
            if (!validate(addressRequest)) return@launch
            addressRequest.entrance = 10
            try {
                RetrofitClient.api.addAddressByUuid(uuid = UUID.fromString(uuid), addressRequest)
                val profile = RetrofitClient.api.getProfileByUuid(UUID.fromString(uuid))
                _mainScreenState.update {
                    it.copy(profile = profile)
                }
            }
           catch (e: Exception){
               _mainScreenState.update {
                   it.copy(error = e.message)
               }
           }
        }
    }
    private fun validate(addressRequest: AddAddressRequest): Boolean{
        if (addressRequest.address.isEmpty()){
            _mainScreenState.update {
                it.copy(error = "Адрес не может быть пустым")
            }
            return false
        }
        if(addressRequest.apartment == null){
            _mainScreenState.update {
                it.copy(error = "Укажите квартиру")
            }
            return false
        }
        if(addressRequest.floor == null){
            _mainScreenState.update {
                it.copy(error = "Укажите этаж")
            }
            return false
        }
        return true
    }
}