package com.example.furintiture.ui.screen.order

import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.PaddingValues
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.material3.Scaffold
import androidx.compose.material3.SnackbarHost
import androidx.compose.material3.SnackbarHostState
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.derivedStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.rememberCoroutineScope
import androidx.compose.ui.Modifier
import androidx.compose.ui.unit.dp
import androidx.lifecycle.viewmodel.compose.viewModel
import com.example.furintiture.ui.common.FurnitureOrderCard
import com.example.furintiture.ui.screen.cart.CartScreenContent
import com.example.furintiture.ui.screen.cart.CartScreenViewModel
import com.example.furintiture.ui.theme.Neutral_20
import kotlinx.coroutines.launch
import java.math.BigDecimal

@Composable
fun OrderScreen(
    uuid: String
) {
    val snackbarHostState  = remember { SnackbarHostState() }
    val coroutineScope = rememberCoroutineScope()
    val viewModel: OrderScreenViewModel = viewModel { OrderScreenViewModel(uuid) }
    Scaffold(
        snackbarHost = {
            SnackbarHost(hostState = snackbarHostState)
        },
        contentColor = Neutral_20
    ) { paddingValues ->
        OrderScreenContent(viewModel, paddingValues){
            coroutineScope.launch {
                snackbarHostState.showSnackbar(it)
            }
        }
    }
}

@Composable
fun OrderScreenContent(
    viewModel: OrderScreenViewModel,
    paddingValues: PaddingValues,
    onErrorCallback : (String) -> Unit
) {
    val state = viewModel.orderScreenState.collectAsState()


    LaunchedEffect(state.value.error) {
        state.value.error?.let(onErrorCallback)
        state.value.error = null
    }
    Column(
        modifier = Modifier
            .padding(paddingValues)
            .fillMaxSize()
            .padding(horizontal = 16.dp)
            .padding(bottom = 100.dp)


    ) {
        Spacer(modifier = Modifier.height(16.dp))
        LazyColumn(
            modifier = Modifier.fillMaxSize(),
            verticalArrangement = Arrangement.spacedBy(16.dp)
        ) {
            items(state.value.orders){
                FurnitureOrderCard(it)
            }
        }
    }
}