package com.example.furintiture.ui.screen.registration

import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.example.furintiture.data.DataStoreSettings
import com.example.furintiture.data.RetrofitClient
import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.flow.asStateFlow
import kotlinx.coroutines.flow.update
import kotlinx.coroutines.launch

class RegistrationScreenViewModel(private val dataStoreSettings: DataStoreSettings): ViewModel() {
    private val _registrationScreenState = MutableStateFlow(RegistrationScreenState())
    val registrationScreenState = _registrationScreenState.asStateFlow()

    fun setPassword(password: String){
        _registrationScreenState.update {
            it.copy(request = it.request.copy(password = password))
        }
    }
    fun setEmail(email: String){
        _registrationScreenState.update {
            it.copy(request = it.request.copy(email = email))
        }
    }
    fun setLastName(lastName: String){
        _registrationScreenState.update {
            it.copy(request = it.request.copy(lastName = lastName))
        }
    }
    fun setFirstName(firstName: String){
        _registrationScreenState.update {
            it.copy(request = it.request.copy(firstName = firstName))
        }
    }

    fun register(){
        if(!validate()) return
        viewModelScope.launch {
            try {
                val result =  RetrofitClient.api.register(_registrationScreenState.value.request)
                dataStoreSettings.setUuid(result.userUuid)
            }
            catch (e: Exception){
                _registrationScreenState.update {
                    it.copy(error = e.message)
                }
            }
        }
    }

    private fun validate(): Boolean{
        if (_registrationScreenState.value.request.email.isEmpty()){
            _registrationScreenState.update {
                it.copy(error = "Введите email")
            }
            return false
        }
        if (_registrationScreenState.value.request.password.isEmpty()){
            _registrationScreenState.update {
                it.copy(error = "Введите password")
            }
            return false
        }
        if (_registrationScreenState.value.request.lastName.isEmpty()){
            _registrationScreenState.update {
                it.copy(error = "Введите фамилию")
            }
            return false
        }
        if (_registrationScreenState.value.request.firstName.isEmpty()){
            _registrationScreenState.update {
                it.copy(error = "Введите имя")
            }
            return false
        }
        return true
    }
}